import { EventEmitter } from '@libp2p/interfaces/events';
import type { PeerDiscovery, PeerDiscoveryEvents } from '@libp2p/interface-peer-discovery';
import { symbol } from '@libp2p/interface-peer-discovery';
import { Components, Initializable } from '@libp2p/components';
export interface BootstrapOptions {
    /**
     * The list of peer addresses in multi-address format
     */
    list: string[];
    /**
     * How long to wait before discovering bootstrap nodes
     */
    timeout?: number;
    /**
     * Tag a bootstrap peer with this name before "discovering" it (default: 'bootstrap')
     */
    tagName?: string;
    /**
     * The bootstrap peer tag will have this value (default: 50)
     */
    tagValue?: number;
    /**
     * Cause the bootstrap peer tag to be removed after this number of ms (default: 2 minutes)
     */
    tagTTL?: number;
}
/**
 * Emits 'peer' events on a regular interval for each peer in the provided list.
 */
export declare class Bootstrap extends EventEmitter<PeerDiscoveryEvents> implements PeerDiscovery, Initializable {
    static tag: string;
    private timer?;
    private readonly list;
    private readonly timeout;
    private components;
    private readonly _init;
    constructor(options?: BootstrapOptions);
    init(components: Components): void;
    get [symbol](): true;
    get [Symbol.toStringTag](): string;
    isStarted(): boolean;
    /**
     * Start emitting events
     */
    start(): void;
    /**
     * Emit each address in the list as a PeerInfo
     */
    _discoverBootstrapPeers(): Promise<void>;
    /**
     * Stop emitting events
     */
    stop(): void;
}
//# sourceMappingURL=index.d.ts.map